////////////////////////////
//
//	WinSetup.prg
//
//	Copyright (C) 1992 Skelton Software, Kendal Cottage, Hillam, Leeds, UK.
//	All Rights Reserved.
//
//	Set up for Windows.
//
////////////////////////////


#include "windows.ch"


//////////////////////////
//
//	WinSetup(cAppNAme, cTitle) --> hWnd
//
//	Registers the window class and creates a window.
//	Returns the handle to the window.
//
//////////////////////////

/*

    WinSetup(<cAppName>, <cTitle>, [ <nX> ], [ <nY> ],                 ;
             [ <nWidth> ], [ <nHeight> ], [ <cIcon> ], [ <cCursor> ],  ;
             [ <nBrush> ], [ <nStyle> ] )  --> hWnd

    Registers the window class and creates a window of that class.

    Optional parameters <nX>, <nY>, <nWidth>, and <nHeight> allow you to
    override the defaults and thus place the main window wherever you
    desire.  <nX> and <nY> are the starting X and Y coordinates.  For
    example, to have the startup window occupy the full screen, you
    could use: WinSetup(appname, app_description, 0, 0, 640, 480)

    Optional parameter <cIcon> is the name of an icon made available to
    the .EXE via a resource compiler.  This icon will be used when the
    application is minimized (i.e., when using Alt-Tab to switch between
    Windows applications).

    Optional parameter <cCursor> is either a pre-defined or user-defined
    cursor to be used as the default mouse cursor for this window class.
    If you pass the name of a user-defined cursor, that must have been
    made available to the .EXE via a resource compiler.

    Optional parameter <nBrush> is one of the stock brushes found in
    WINDOWS.CH (e.g., WHITE_BRUSH, etcetera).  This will be used as the
    background drawing brush for this window class.

    <nStyle> is an optional numeric parameter specifying the window style
    to use.  This should be a combination of the WS_* values defined
    in WINDOWS.CH (such as WS_OVERLAPPEDWINDOW + WS_CLIPCHILDREN).
    The default is WS_OVERLAPPEDWINDOW.

    Returns:  A handle to the newly created window

*/


function WinSetup(cAppName, cTitle, nX, nY, nWidth, nHeight, ;
                  cIcon, cCursor, nBrush, nStyle)
local hWnd
local hInst     := _GetInstance()
local hPrevInst := _GetPrevInstance()
local nCmdShow  := _GetnCmdShow()
local hCursor	// NOTE: 0 would mean no cursor,
		//	 nil means default: LoadCursor( , IDC_ARROW)
local hBrush	// nil means default: GetStockObject(WHITE_BRUSH)
local hIcon	// nil means default: LoadIcon( , IDI_APPLICATION)

if hPrevInst == 0
   // set up icon if one was specified
   if cIcon <> NIL
      hIcon := LoadIcon(hInst,cIcon)
   endif

   // set up cursor if one was specified
   if cCursor <> NIL
      hCursor := LoadCursor(hInst, cCursor)
   endif

   // set up background brush if one was specified
   if nBrush <> NIL
      hBrush := GetStockObject(nBrush)
   endif

   if ! RegisterClass(CS_HREDRAW + CS_VREDRAW + CS_SAVEBITS         ;
                      ;  // remove next line to suppress mouse doubleclicks
                      + CS_DBLCLKS, ;
                      hInst,        ;    // application instance
                      hIcon,        ;    // default icon
                      hCursor,      ;    // default cursor
                      hBrush,       ;    // default background brush
                      cAppName)          // app name

      // probably out of resources
      quit
   endif
endif

// assign default values for X, Y coordinates, and height/width
if nX == NIL
   nX := CW_USEDEFAULT
endif
if nY == NIL
   nY := CW_USEDEFAULT
endif
if nWidth == NIL
   nWidth := CW_USEDEFAULT
endif
if nHeight == NIL
   nHeight := CW_USEDEFAULT
endif

if nStyle == nil
   nStyle = WS_OVERLAPPEDWINDOW
endif

hWnd := CreateWindow(cAppName,          ;       // window class
		    cTitle, 		;	// caption for title bar
		    nStyle,		;	// window style
                    nX,                 ;       // x co-ordinate
                    nY,                 ;       // y co-ordinate
                    nWidth,             ;       // width
                    nHeight,            ;       // height
		    0,			;	// hWnd of parent (none)
		    0,			;	// hMenu of menu (none yet)
		    hInst)			// our own app instance

if hWnd == 0
   MessageBox(, "Window Creation Failed!", "Error", MB_ICONEXCLAMATION + MB_OK)
   hWnd := NIL
endif

// make sure it's displayed ...
ShowWindow(hWnd, nCmdShow)

// ... and up to date
UpdateWindow(hWnd)

return hWnd

// end of file WINSETUP.PRG
